@@ -1,13 +1,13 @@
 contrib <- function(otutab, siteInCol=TRUE, taxhead=NULL, threshold = 1, percent=FALSE, check="rare", write=FALSE, plot=FALSE, ...) {
   if (!siteInCol) {
     message("Site headers in columns, will be transposed")
-    otutab = typeConvert(otutab=data.frame(t(otutab),stringsAsFactors = FALSE),taxhead = taxhead)
+    otutab = typeConvert(otutab=as.data.frame(t(otutab)),taxhead = taxhead)
   }
   if (!is.null(taxhead)){
     message("The taxonomy column will be not used in calculating the Bray contribution")
     otutab = otutab[,-match(taxhead, colnames(otutab))]
   }
-  otutab = data.frame(t(otutab),stringsAsFactors = FALSE)
+  otutab = as.data.frame(t(otutab))
   if(!percent) {relabund <- sweep(otutab,1,rowSums(otutab),"/")*100
   } else {relabund = otutab}
   if (grepl(check,"R|rare")) {
@@ -21,7 +21,8 @@ contrib <- function(otutab, siteInCol=TRUE, taxhead=NULL, threshold = 1, percent
   } else {stop("Invalid choice! Work only for abundant and rare biosphere")}
   print(paste("Dimemsion of subsampled taxa table", dim(sub)[1],"rows,",dim(sub)[2], "columns"))
   distp <- pbray(allComm = relabund, subComm = sub)
-  distot <- vegdist(relabund, method ='bray')
+  ## distot = vegdist(relabund, method='bray')
+  distot <- calc_bc(relabund)
   r1 <- matrixConvert(distp,colname = c("sample1","sample2","pBrayCurtis"))
   r2 <- matrixConvert(distot,colname = c("sample1","sample2","totalBrayCurtis"))
   r3 <- matrixConvert(distp/distot,colname = c("sample1","sample2","Contribution"))
