@@ -1,4 +1,4 @@
-otuReport <- function(otutab, siteInCol=TRUE, taxhead='taxonomy', platform ='mothur', pattern=';', prefix=TRUE, percent=FALSE, taxlevel='phylum', collap = "->"){
+otuReport <- function(otutab, siteInCol=TRUE, taxhead='taxonomy', platform ='mothur', pattern=';', prefix=TRUE, percent=FALSE, taxlevel='phylum', collap = ";"){
   message(rep('= = ',times = 15))
   message('Data checking ... ')
   taxlab = tolower(taxhead)
